@@ -70,6 +70,8 @@ API_PATH = {
     'scope_remove_manager': 'api/v3/scopes/{scope_id}/remove_manager',
     'scope_add_leadmember': 'api/v3/scopes/{scope_id}/add_leadmember',
     'scope_remove_leadmember': 'api/v3/scopes/{scope_id}/remove_leadmember',
+    'scope_add_supervisor': 'api/v3/scopes/{scope_id}/add_supervisor',
+    'scope_remove_supervisor': 'api/v3/scopes/{scope_id}/remove_supervisor',
     'scopes': 'api/v3/scopes.json',
     'scopes_clone': 'api/v3/scopes/clone',
     'parts': 'api/v3/parts.json',
