@@ -244,6 +244,8 @@ class WidgetNames(Enum):
     :cvar MULTICOLUMNWIDGET: multiColumnWidget
     :cvar PROGRESSWIDGET: progressWidget
     :cvar TASKSWIDGET: tasksWidget
+    :cvar SERVICECARDWIDGET: serviceCardWidget
+    :cvar DASHBOARDWIDGET: 'dashboardWidget'
     """
 
     SUPERGRIDWIDGET = 'superGridWidget'
@@ -261,6 +263,8 @@ class WidgetNames(Enum):
     CARDWIDGET = 'cardWidget'
     PROGRESSWIDGET = 'progressWidget'
     TASKSWIDGET = 'taskWidget'
+    SERVICECARDWIDGET = 'serviceCardWidget'
+    DASHBOARDWIDGET = 'dashboardWidget'
 
 
 class WidgetTypes(Enum):
@@ -285,6 +289,8 @@ class WidgetTypes(Enum):
     :cvar CARD: Card widget
     :cvar TASKS: Tasks widget
     :cvar WEATHER: Weather widget
+    :cvar SERVICECARD: Servicecard widget
+    :cvar DASHBOARD: Dashboard widget
     """
 
     UNDEFINED = 'UNDEFINED'
@@ -306,6 +312,8 @@ class WidgetTypes(Enum):
     CARD = 'CARD'
     TASKS = 'TASKS'
     WEATHER = 'WEATHER'
+    SERVICECARD = 'SERVICECARD'
+    DASHBOARD = 'DASHBOARD'
 
 
 WidgetCompatibleTypes = {
@@ -323,7 +331,9 @@ WidgetCompatibleTypes = {
     WidgetNames.PROGRESSWIDGET: WidgetTypes.PROGRESS,
     WidgetNames.SIGNATUREWIDGET: WidgetTypes.SIGNATURE,
     WidgetNames.CARDWIDGET: WidgetTypes.CARD,
-    WidgetNames.TASKSWIDGET: WidgetTypes.TASKS
+    WidgetNames.TASKSWIDGET: WidgetTypes.TASKS,
+    WidgetNames.SERVICECARDWIDGET: WidgetTypes.SERVICECARD,
+    WidgetNames.DASHBOARDWIDGET: WidgetTypes.DASHBOARD
 }
 
 default_metapanel_widget = dict(
@@ -471,11 +481,13 @@ class ScopeRoles(Enum):
     Roles that exist for a member of a scope.
 
     :cvar MANAGER: owner of the scope, has full rights
-    :cvar LEADMEMBER: elevated member, has assignment rights
+    :cvar SUPERVISOR: supervisor member of a scope, has the rights as leadmember and rights to manage catalog tasks.
+    :cvar LEADMEMBER: elevated member, has assignment rights, no rights on App tasks or Catalog tasks.
     :cvar MEMBER: normal member, only has viewing rights
     """
 
     MANAGER = "manager"
+    SUPERVISOR = "supervisor"
     LEADMEMBER = "leadmember"
     MEMBER = "member"
 
@@ -529,7 +541,7 @@ class SortTable(Enum):
 
 
 class Alignment(Enum):
-    """The acceptable alignment options for attachment viewer and navigation bar widgets.
+    """The acceptable alignment options for attachment viewer, navigation bar widgets and service widgets.
 
     :cvar LEFT: Aligned to the left
     :cvar CENTER: Aligned to the center
