@@ -20,6 +20,7 @@ from pykechain.models.widgets.widget_schemas import undefined_meta_schema
 # SIGNATURE = 'SIGNATURE'
 # CARD = 'CARD'
 # WEATHER = 'WEATHER'
+# DASHBOARD = 'DASHBOARD'
 
 
 class MetapanelWidget(Widget):
@@ -98,3 +99,11 @@ class TasksWidget(Widget):
 
 class WeatherWidget(Widget):
     """Weather Widget."""
+
+
+class ServicecardWidget(Widget):
+    """ServiceCard Widget."""
+
+
+class DashboardWidget(Widget):
+    """Dashboard Widget."""
