@@ -2,13 +2,16 @@ import warnings
 from typing import Iterable, Union, Optional, Text, Dict, List, Any
 
 from pykechain.enums import SortTable, WidgetTypes, ShowColumnTypes, ScopeWidgetColumnTypes, \
-    ProgressBarColors, PropertyType, CardWidgetImageValue, CardWidgetLinkValue, LinkTargets, ImageFitValue, \
-    KEChainPages, CardWidgetKEChainPageLink, Alignment, ActivityType
+    ProgressBarColors, CardWidgetLinkValue, LinkTargets, ImageFitValue, \
+    KEChainPages, Alignment
+from pykechain.models.widgets.enums import DashboardWidgetSourceScopes, DashboardWidgetShowTasks, \
+    DashboardWidgetShowScopes
 from pykechain.exceptions import NotFoundError, IllegalArgumentError
 from pykechain.models.input_checks import check_enum, check_text, check_base, check_type, check_list_of_text
+from pykechain.models.value_filter import PropertyValueFilter
 from pykechain.models.widgets import Widget
 from pykechain.models.widgets.helpers import _set_title, _initiate_meta, _retrieve_object, _retrieve_object_id, \
-    _check_prefilters, _check_excluded_propmodels
+    _check_prefilters, _check_excluded_propmodels, _set_description, _set_link, _set_image, _set_button_text
 from pykechain.utils import is_uuid, find, snakecase, is_url
 
 
@@ -318,36 +321,38 @@ class WidgetsManager(Iterable):
         )
         return widget
 
-    def add_filteredgrid_widget(self,
-                                part_model: Union['Part', Text],
-                                parent_instance: Optional[Union['Part', Text]] = None,
-                                title: Optional[Union[type(None), Text, bool]] = False,
-                                parent_widget: Optional[Union[Widget, Text]] = None,
-                                new_instance: Optional[bool] = True,
-                                edit: Optional[bool] = True,
-                                clone: Optional[bool] = True,
-                                export: Optional[bool] = True,
-                                upload: Optional[bool] = True,
-                                delete: Optional[bool] = False,
-                                incomplete_rows: Optional[bool] = True,
-                                emphasize_new_instance: Optional[bool] = True,
-                                emphasize_edit: Optional[bool] = False,
-                                emphasize_clone: Optional[bool] = False,
-                                emphasize_delete: Optional[bool] = False,
-                                sort_property: Optional[Union['AnyProperty', Text]] = None,
-                                sort_name: Optional[Union[bool, Text]] = False,
-                                sort_direction: Optional[Union[SortTable, Text]] = SortTable.ASCENDING,
-                                show_name_column: Optional[bool] = True,
-                                show_images: Optional[bool] = False,
-                                collapse_filters: Optional[bool] = False,
-                                page_size: Optional[int] = 25,
-                                readable_models: Optional[List[Union['AnyProperty', Text]]] = None,
-                                writable_models: Optional[List[Union['AnyProperty', Text]]] = None,
-                                all_readable: Optional[bool] = False,
-                                all_writable: Optional[bool] = False,
-                                excluded_propmodels: Optional[List[Union['AnyProperty', Text]]] = None,
-                                prefilters: Optional[Dict] = None,
-                                **kwargs) -> Widget:
+    def add_filteredgrid_widget(
+        self,
+        part_model: Union['Part', Text],
+        parent_instance: Optional[Union['Part', Text]] = None,
+        title: Optional[Union[type(None), Text, bool]] = False,
+        parent_widget: Optional[Union[Widget, Text]] = None,
+        new_instance: Optional[bool] = True,
+        edit: Optional[bool] = True,
+        clone: Optional[bool] = True,
+        export: Optional[bool] = True,
+        upload: Optional[bool] = True,
+        delete: Optional[bool] = False,
+        incomplete_rows: Optional[bool] = True,
+        emphasize_new_instance: Optional[bool] = True,
+        emphasize_edit: Optional[bool] = False,
+        emphasize_clone: Optional[bool] = False,
+        emphasize_delete: Optional[bool] = False,
+        sort_property: Optional[Union['AnyProperty', Text]] = None,
+        sort_name: Optional[Union[bool, Text]] = False,
+        sort_direction: Optional[Union[SortTable, Text]] = SortTable.ASCENDING,
+        show_name_column: Optional[bool] = True,
+        show_images: Optional[bool] = False,
+        collapse_filters: Optional[bool] = False,
+        page_size: Optional[int] = 25,
+        readable_models: Optional[List[Union['AnyProperty', Text]]] = None,
+        writable_models: Optional[List[Union['AnyProperty', Text]]] = None,
+        all_readable: Optional[bool] = False,
+        all_writable: Optional[bool] = False,
+        excluded_propmodels: Optional[List[Union['AnyProperty', Text]]] = None,
+        prefilters: Optional[Union[List[PropertyValueFilter], Dict]] = None,
+        **kwargs
+    ) -> Widget:
         """
         Add a KE-chain superGrid (e.g. basic table widget) to the customization.
 
@@ -412,7 +417,8 @@ class WidgetsManager(Iterable):
         :type all_writable: bool
         :param excluded_propmodels: (O) list of properties not shown in the filter pane
         :type excluded_propmodels: list
-        :param prefilters: (O) default filters active in the grid, defined as a dict with the following fields:
+        :param prefilters: (O) default filters active in the grid.
+            Defined as either a list of PropertyValueFilter objects or a dict with the following fields:
             * property_models: list of Properties, defined as Property objects or UUIDs
             * values: the pre-filter value for each property to filter on
             * filters_type: the types of filters, either `le`, `ge`, `icontains` or `exact`
@@ -433,8 +439,8 @@ class WidgetsManager(Iterable):
         meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
         if prefilters:
             list_of_prefilters = _check_prefilters(part_model=part_model, prefilters=prefilters)
-            prefilters = {'property_value': ','.join(list_of_prefilters) if list_of_prefilters else {}}
-            meta['prefilters'] = prefilters
+            prefilters = {"property_value": ",".join([pf.format() for pf in list_of_prefilters])}
+            meta["prefilters"] = prefilters
         if excluded_propmodels:
             excluded_propmodels = _check_excluded_propmodels(part_model=part_model,
                                                              property_models=excluded_propmodels)
@@ -724,15 +730,18 @@ class WidgetsManager(Iterable):
         )
         return widget
 
-    def add_service_widget(self,
-                           service: 'Service',
-                           title: Optional[Union[type(None), bool, Text]] = False,
-                           custom_button_text: Optional[Text] = False,
-                           emphasize_run: Optional[bool] = True,
-                           download_log: Optional[bool] = False,
-                           show_log: Optional[bool] = True,
-                           parent_widget: Optional[Union[Widget, Text]] = None,
-                           **kwargs) -> Widget:
+    def add_service_widget(
+        self,
+        service: 'Service',
+        title: Optional[Union[type(None), bool, Text]] = False,
+        custom_button_text: Optional[Text] = False,
+        emphasize_run: Optional[bool] = True,
+        alignment: Optional[Alignment] = Alignment.LEFT,
+        download_log: Optional[bool] = False,
+        show_log: Optional[bool] = True,
+        parent_widget: Optional[Union[Widget, Text]] = None,
+        **kwargs
+    ) -> Widget:
         """
         Add a KE-chain Service (e.g. script widget) to the widget manager.
 
@@ -752,6 +761,8 @@ class WidgetsManager(Iterable):
         :type custom_button_text: bool or basestring or None
         :param emphasize_run: Emphasize the run button (default True)
         :type emphasize_run: bool
+        :param alignment: Horizontal alignment of the button
+        :type alignment: Alignment
         :param download_log: Include the possibility of downloading the log inside the activity (default False)
         :type download_log: bool
         :param show_log: Include the log message inside the activity (default True)
@@ -768,32 +779,20 @@ class WidgetsManager(Iterable):
         service = _retrieve_object(obj=service, method=self._client.service)  # type: 'Service'  # noqa
 
         meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
-
-        # Add custom button text
-        if custom_button_text is False:
-            show_button_value = "Default"
-            button_text = service.name
-        elif custom_button_text is None:
-            show_button_value = "No text"
-            button_text = ''
-        else:
-            show_button_value = "Custom text"
-            button_text = str(custom_button_text)
+        meta, title = _set_title(meta, title=title, **kwargs)
+        meta = _set_button_text(meta, custom_button_text=custom_button_text, service=service, **kwargs)
 
         from pykechain.models import Service
-        service_id = check_base(service, Service, 'service', method=self._client.service)
+        service_id = check_base(service, Service, "service", method=self._client.service)
 
         meta.update({
-            'showButtonValue': show_button_value,
-            'customText': button_text,
-            'serviceId': service_id,
-            'emphasizeButton': emphasize_run,
-            'showDownloadLog': check_type(download_log, bool, 'download_log'),
-            'showLog': True if download_log else check_type(show_log, bool, 'show_log'),
+            "serviceId": service_id,
+            "emphasizeButton": emphasize_run,
+            "showDownloadLog": check_type(download_log, bool, "download_log"),
+            "showLog": True if download_log else check_type(show_log, bool, "show_log"),
+            "alignment": check_enum(alignment, Alignment, "alignment"),
         })
 
-        meta, title = _set_title(meta, title=title, **kwargs)
-
         widget = self.create_widget(
             widget_type=WidgetTypes.SERVICE,
             title=title,
@@ -1091,7 +1090,7 @@ class WidgetsManager(Iterable):
                          search_filter: Optional[bool] = True,
                          **kwargs) -> Widget:
         """
-        Add a KE-chain Scope widget to the Widgetmanager and the activity.
+        Add a KE-chain Scope widget to the WidgetManager and the activity.
 
         The widget will be saved in KE-chain.
 
@@ -1216,6 +1215,8 @@ class WidgetsManager(Iterable):
             * String value: Custom title
             * None: No title
         :type title: bool or basestring or None
+        :param parent_widget: (O) parent of the widget for Multicolumn and Multirow widget.
+        :type parent_widget: Widget or basestring or None
         :param custom_button_text: Custom text for 'Add signature' button
         :type custom_button_text: bool or basestring
         :param custom_undo_button_text: Custom text for 'Remove signature' button
@@ -1277,7 +1278,7 @@ class WidgetsManager(Iterable):
                         link: Optional[Union[type(None), Text, bool, KEChainPages]] = None,
                         link_value: Optional[CardWidgetLinkValue] = None,
                         link_target: Optional[Union[Text, LinkTargets]] = LinkTargets.SAME_TAB,
-                        image_fit: Optional[Union[ImageFitValue, Text]] = ImageFitValue.CONTAIN,
+                        image_fit: Optional[Union[Text, ImageFitValue]] = ImageFitValue.CONTAIN,
                         **kwargs) -> Widget:
         """
         Add a KE-chain Card widget to the WidgetManager and the activity.
@@ -1298,6 +1299,8 @@ class WidgetsManager(Iterable):
             * task: another KE-chain task, provided as an Activity object or its UUID
             * String value: URL to a webpage
             * KE-chain page: built-in KE-chain page of the current scope
+        :param parent_widget: (O) parent of the widget for Multicolumn and Multirow widget.
+        :type parent_widget: Widget or basestring or None
         :param link_value: Overwrite the default link value (obtained from the type of the link)
         :type link_value: CardWidgetLinkValue
         :param link_target: how the link is opened, one of the values of CardWidgetLinkTarget enum.
@@ -1308,84 +1311,16 @@ class WidgetsManager(Iterable):
         """
         meta = _initiate_meta(kwargs, activity=self.activity)
         meta, title = _set_title(meta, title=title, **kwargs)
-
-        # Process the description
-        if description is False or description is None:
-            show_description_value = "No description"
-            description = ""
-        elif isinstance(description, str):
-            show_description_value = "Custom description"
-        else:
-            raise IllegalArgumentError("When using the add_card_widget, 'description' must be 'text_type' or None or "
-                                       "False. Type is: {}".format(type(description)))
-
-        meta.update({
-            "showDescriptionValue": show_description_value,
-            "customDescription": description
-        })
-
-        # Process the image it is linked to
-        from pykechain.models import Property
-        if isinstance(image, Property) and image.type == PropertyType.ATTACHMENT_VALUE:
-            meta.update({
-                'customImage': "/api/v3/properties/{}/preview".format(image.id),
-                'showImageValue': CardWidgetImageValue.CUSTOM_IMAGE
-            })
-        elif image is None:
-            meta.update({
-                'customImage': None,
-                'showImageValue': CardWidgetImageValue.NO_IMAGE
-            })
-        else:
-            raise IllegalArgumentError("When using the add_card_widget, 'image' must be a Property or None. Type "
-                                       "is: {}".format(type(image)))
-
-        from pykechain.models import Activity
-        if isinstance(link, Activity):
-            if link.activity_type == ActivityType.TASK:
-                default_link_value = CardWidgetLinkValue.TASK_LINK
-            else:
-                default_link_value = CardWidgetLinkValue.TREE_VIEW
-
-            meta.update({
-                'customLink': link.id,
-                'showLinkValue': default_link_value,
-            })
-        elif isinstance(link, str) and is_uuid(link):
-            meta.update({
-                'customLink': link,
-                'showLinkValue': CardWidgetLinkValue.TASK_LINK,
-            })
-        elif link is None or link is False:
-            meta.update({
-                'customLink': None,
-                'showLinkValue': CardWidgetLinkValue.NO_LINK,
-            })
-        elif link in KEChainPages.values():
-            meta.update({
-                'customLink': "",
-                'showLinkValue': CardWidgetKEChainPageLink[link],
-            })
-        else:
-            meta.update({
-                'customLink': link,
-                'showLinkValue': CardWidgetLinkValue.EXTERNAL_LINK,
-            })
-
-        if link_value is not None:
-            meta.update({
-                'showLinkValue': check_enum(link_value, CardWidgetLinkValue, 'link_value'),
-            })
-
-        meta['linkTarget'] = check_enum(link_target, LinkTargets, 'link_target')
-        meta['imageFit'] = check_enum(image_fit, ImageFitValue, 'image_fit')
+        meta = _set_description(meta, description=description, **kwargs)
+        meta = _set_link(meta, link=link, link_value=link_value, link_target=link_target, **kwargs)
+        meta = _set_image(meta, image=image, image_fit=image_fit, **kwargs)
 
         widget = self.create_widget(
             widget_type=WidgetTypes.CARD,
             meta=meta,
             title=title,
             parent=parent_widget,
-            **kwargs,
+            **kwargs
         )
         return widget
 
@@ -1407,6 +1342,8 @@ class WidgetsManager(Iterable):
             * String value: Custom title
             * None: No title
         :type title: bool or basestring or None
+        :param parent_widget: (O) parent of the widget for Multicolumn and Multirow widget.
+        :type parent_widget: Widget or basestring or None
         :param kwargs: additional keyword arguments to pass
         :return: newly created widget
         :rtype: Widget
@@ -1431,6 +1368,240 @@ class WidgetsManager(Iterable):
         )
         return widget
 
+    def add_service_card_widget(
+        self,
+        service: 'Service',
+        image: Optional['AttachmentProperty'] = None,
+        title: Optional[Union[type(None), bool, Text]] = False,
+        description: Optional[Union[Text]] = None,
+        parent_widget: Optional[Union[Widget, Text]] = None,
+        custom_button_text: Optional[Text] = False,
+        emphasize_run: Optional[bool] = True,
+        alignment: Optional[Alignment] = Alignment.LEFT,
+        link: Optional[Union[type(None), Text, bool, KEChainPages]] = None,
+        link_value: Optional[CardWidgetLinkValue] = None,
+        link_target: Optional[Union[Text, LinkTargets]] = LinkTargets.SAME_TAB,
+        image_fit: Optional[Union[ImageFitValue, Text]] = ImageFitValue.CONTAIN,
+        **kwargs
+    ) -> Widget:
+        """
+        Add a KE-chain Service Card widget to the WidgetManager and the activity.
+
+        The widget will be saved in KE-chain.
+
+        :param service: The Service to which the button will be coupled and will be ran when the button is pressed.
+        :type service: :class:`Service` or UUID
+        :param image: AttachmentProperty providing the source of the image shown in the card widget.
+        :param title: A custom title for the card widget
+            * False (default): Card name
+            * String value: Custom title
+            * None: No title
+        :param description: Custom text shown below the image in the card widget
+            * False (default): Card name
+            * String value: Custom title
+            * None: No title
+        :param parent_widget: (O) parent of the widget for Multicolumn and Multirow widget.
+        :type parent_widget: Widget or basestring or None
+        :param custom_button_text: A custom text for the button linked to the script
+            * False (default): Script name
+            * String value: Custom title
+            * None: No title
+        :type custom_button_text: bool or basestring or None
+        :param emphasize_run: Emphasize the run button (default True)
+        :type emphasize_run: bool
+        :param alignment: Horizontal alignment of the button
+        :type alignment: Alignment
+        :param link: Where the card widget refers to. This can be one of the following:
+            * None (default): no link
+            * task: another KE-chain task, provided as an Activity object or its UUID
+            * String value: URL to a webpage
+            * KE-chain page: built-in KE-chain page of the current scope
+        :param link_value: Overwrite the default link value (obtained from the type of the link)
+        :type link_value: CardWidgetLinkValue
+        :param link_target: how the link is opened, one of the values of CardWidgetLinkTarget enum.
+        :type link_target: CardWidgetLinkTarget
+        :param image_fit: how the image on the card widget is displayed
+        :type image_fit: ImageFitValue
+        :return: Service Card Widget
+        """
+        # Check whether the script is uuid type or class `Service`
+        service = _retrieve_object(obj=service, method=self._client.service)  # type: 'Service'  # noqa
+
+        meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
+        meta = _set_description(meta, description=description, **kwargs)
+        meta = _set_link(meta, link=link, link_value=link_value, link_target=link_target, **kwargs)
+        meta = _set_image(meta, image=image, image_fit=image_fit, **kwargs)
+        meta = _set_button_text(meta, custom_button_text=custom_button_text, service=service, **kwargs)
+
+        from pykechain.models import Service
+        service_id = check_base(service, Service, 'service', method=self._client.service)
+
+        meta.update({
+            'serviceId': service_id,
+            'emphasizeButton': emphasize_run,
+            "alignment": check_enum(alignment, Alignment, "alignment"),
+        })
+
+        widget = self.create_widget(
+            widget_type=WidgetTypes.SERVICECARD,
+            meta=meta,
+            title=title,
+            parent=parent_widget,
+            **kwargs
+        )
+        return widget
+
+    def add_dashboard_widget(
+        self,
+        title: Optional[Union[bool, Text]] = False,
+        parent_widget: Optional[Union[Widget, Text]] = None,
+        source_scopes: [DashboardWidgetSourceScopes] = DashboardWidgetSourceScopes.CURRENT_SCOPE,
+        source_scopes_tags: Optional[List] = None,
+        source_subprocess: Optional[List] = None,
+        source_selected_scopes: Optional[List] = None,
+        show_tasks: Optional[List[DashboardWidgetShowTasks]] = None,
+        show_scopes: Optional[List[DashboardWidgetShowScopes]] = None,
+        no_background: Optional[bool] = False,
+        show_assignees: Optional[bool] = True,
+        show_assignees_table: Optional[bool] = True,
+        show_open_task_assignees: Optional[bool] = True,
+        show_open_vs_closed_tasks: Optional[bool] = True,
+        show_open_closed_tasks_assignees: Optional[bool] = True,
+        **kwargs
+    ) -> Widget:
+        """
+        Add a KE-chain Dashboard Widget to the WidgetManager and the activity.
+
+        The widget will be saved in KE-chain
+
+        :param title: A custom title for the card widget
+            * False (default): Card name
+            * String value: Custom title
+            * None: No title
+        :param parent_widget: (O) parent of the widget for Multicolumn and Multirow widget.
+        :type parent_widget: Widget or basestring or None
+        :param source_scopes: The `Project(s)` to be used as source when displaying the Widget.
+            Defaults on CURRENT_SCOPE.
+        :type source_scopes: basestring (see :class:`models.widgets.enums.DashboardWidgetSourceScopes`)
+        :param source_scopes_tags: Tags on which the source projects can be filtered on. Source is selected
+            automatically as TAGGED_SCOPES
+        :type source_scopes_tags: list of tags
+        :param source_subprocess: Subprocess that the `Widget` uses as source. Source is selected automatically
+            SUBPROCESS
+        :type source_subprocess: list of str (UUID of an `Activity`)
+        :param source_selected_scopes: List of `Scope` to be used by the `Widget` as source. Source is selected
+            automatically as SELECTED_SCOPES
+        :type source_selected_scopes: list of str (UUIDs of `Scopes`)
+        :param show_tasks: Type of tasks to be displayed in the `Widget`. If left None, all of them will be selected
+        :type show_tasks: list of basestring (see :class:`models.widgets.enums.DashboardWidgetShowTasks`)
+        :param show_scopes: Type of scopes to be displayed in the `Widget`. If left None, all of them will be selected
+        :type show_scopes: list of basestring (see :class:`models.widgets.enums.DashboardWidgetShowScopes`)
+        :param no_background: Reverse the shadows (default False)
+        :type no_background: bool
+        :param show_assignees: Show the assignees pie chart
+        :type show_assignees: bool
+        :param show_assignees_table: Show the assignees table
+        :type show_assignees_table: bool
+        :param show_open_task_assignees: Show the `Open tasks per assignees` pie chart
+        :type show_open_task_assignees: bool
+        :param show_open_vs_closed_tasks: Show the `Open vs closed tasks` pie chart
+        :type show_open_vs_closed_tasks: bool
+        :param show_open_closed_tasks_assignees: Show the `Open open and closed tasks per assignees` pie chart
+        :type show_open_closed_tasks_assignees: bool
+        :param kwargs:
+        :return:
+        """
+        meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
+
+        if source_scopes_tags:
+            meta.update({
+                'source': DashboardWidgetSourceScopes.TAGGED_SCOPES,
+                'scopeTag': check_type(source_scopes_tags, list, 'source_scopes_tags')
+            })
+        elif source_subprocess:
+            meta.update({
+                'source': DashboardWidgetSourceScopes.SUBPROCESS,
+                'scopeTag': check_type(source_subprocess, list, 'source_subprocess')
+            })
+        elif source_selected_scopes:
+            meta.update({
+                'source': DashboardWidgetSourceScopes.SELECTED_SCOPES,
+                'scopeList': check_type(source_selected_scopes, list, 'source_selected_scopes')
+            })
+        else:
+            meta.update({
+                'source': check_enum(source_scopes, DashboardWidgetSourceScopes, 'source_scopes')
+            })
+
+        show_tasks_list = list()
+        if show_tasks is None:
+            for value in DashboardWidgetShowTasks.values():
+                show_tasks_list.append({
+                    'name': value,
+                    'order': DashboardWidgetShowTasks.values().index(value),
+                    'selected': True
+                })
+        else:
+            check_type(show_tasks, list, 'show_tasks')
+            for value in DashboardWidgetShowTasks.values():
+                if value in show_tasks:
+                    show_tasks_list.append({
+                        'name': value,
+                        'order': DashboardWidgetShowTasks.values().index(value),
+                        'selected': True
+                    })
+                else:
+                    show_tasks_list.append({
+                        'name': value,
+                        'order': DashboardWidgetShowTasks.values().index(value),
+                        'selected': False
+                    })
+
+        show_projects_list = list()
+        if show_scopes is None:
+            for value in DashboardWidgetShowScopes.values():
+                show_projects_list.append({
+                    'name': value,
+                    'order': DashboardWidgetShowScopes.values().index(value),
+                    'selected': True
+                })
+        else:
+            check_type(show_tasks, list, 'show_tasks')
+            for value in DashboardWidgetShowScopes.values():
+                if value in show_scopes:
+                    show_projects_list.append({
+                        'name': value,
+                        'order': DashboardWidgetShowScopes.values().index(value),
+                        'selected': True
+                    })
+                else:
+                    show_projects_list.append({
+                        'name': value,
+                        'order': DashboardWidgetShowScopes.values().index(value),
+                        'selected': False
+                    })
+        meta.update({
+            'showNumbers': show_tasks_list,
+            'showNumbersProjects': show_projects_list,
+            'noBackground': check_type(no_background, bool, 'no_background'),
+            'showAssignees': check_type(show_assignees, bool, 'show_assignees'),
+            'showAssigneesTable': check_type(show_assignees_table, bool, 'show_assignees_table'),
+            'showOpenTaskAssignees': check_type(show_open_task_assignees, bool, 'show_open_task_assignees'),
+            'showOpenVsClosedTasks': check_type(show_open_vs_closed_tasks, bool, 'show_open_vs_closed_tasks'),
+            'showOpenClosedTasksAssignees': check_type(
+                show_open_closed_tasks_assignees, bool, 'show_open_closed_tasks_assignees')
+        })
+
+        widget = self.create_widget(
+            widget_type=WidgetTypes.DASHBOARD,
+            meta=meta,
+            title=title,
+            parent=parent_widget,
+            **kwargs
+        )
+        return widget
     #
     # Widget manager methods
     #
