@@ -4,6 +4,8 @@ from pykechain.enums import (WidgetTypes, ShowColumnTypes, FilterType, ProgressB
                              Category, LinkTargets, KEChainPages, WidgetTitleValue, Alignment, ActivityType,
                              CardWidgetLinkValue, CardWidgetLinkTarget, ImageFitValue, PropertyType, Classification,
                              Multiplicity)
+from pykechain.models.widgets.enums import DashboardWidgetSourceScopes, DashboardWidgetShowTasks, \
+    DashboardWidgetShowScopes
 from pykechain.exceptions import IllegalArgumentError, NotFoundError
 from pykechain.models import Activity, Part
 from pykechain.models.widgets import (
@@ -12,6 +14,7 @@ from pykechain.models.widgets import (
     MetapanelWidget, ScopeWidget)
 from pykechain.models.widgets.helpers import _set_title
 from pykechain.models.widgets.widget import Widget
+from pykechain.models.widgets.widget_models import ServicecardWidget, DashboardWidget
 from pykechain.models.widgets.widgets_manager import WidgetsManager
 from pykechain.utils import slugify_ref
 from tests.classes import TestBetamax
@@ -288,7 +291,7 @@ class TestWidgetManagerInActivity(TestBetamax):
         self.assertEqual(len(self.wm), 1 + 1)
         self.assertEqual("Picture", widget.title_visible)
 
-    def test_attachment_widget_with_associations_using_widget_manager(self):
+    def test_add_attachment_widget_with_associations_using_widget_manager(self):
         photo_property = self.project.property("Picture")
 
         widget = self.wm.add_attachmentviewer_widget(
@@ -300,7 +303,7 @@ class TestWidgetManagerInActivity(TestBetamax):
         self.assertIsInstance(widget, AttachmentviewerWidget)
         self.assertEqual(len(self.wm), 1 + 1)
 
-    def test_attachment_widget_with_editable_association(self):
+    def test_add_attachment_widget_with_editable_association(self):
         photo_property = self.project.property("Picture")
 
         widget = self.wm.add_attachmentviewer_widget(
@@ -453,7 +456,7 @@ class TestWidgetManagerInActivity(TestBetamax):
         self.assertEqual(len(self.wm), 9, msg='New KE-chain page has been added to the Enum, '
                                               'check if the mapping dicts in enums.py need updating too!')
 
-    def test_service_widget(self):
+    def test_add_service_widget(self):
         service_gears_successful = self.project.service("Service Gears - Successful")
 
         widget1 = self.wm.add_service_widget(service=service_gears_successful)
@@ -492,7 +495,7 @@ class TestWidgetManagerInActivity(TestBetamax):
 
         self.assertEqual(widget_2.ref, slugify_ref('Caught in a landslide'))
 
-    def test_metapanel_widget(self):
+    def test_add_metapanel_widget(self):
         widget = self.wm.add_metapanel_widget(
             show_all=True,
             show_progress=True,
@@ -516,7 +519,7 @@ class TestWidgetManagerInActivity(TestBetamax):
         )
         self.assertEqual(len(self.wm), 1 + 1)
 
-    def test_progress_widget(self):
+    def test_add_progress_widget(self):
         self.wm.add_progress_widget(custom_height=35,
                                     show_progress_text=False)
         self.assertEqual(len(self.wm), 1 + 1)
@@ -546,7 +549,7 @@ class TestWidgetManagerInActivity(TestBetamax):
 
         self.assertNotIn(widget_one, self.wm)
 
-    def test_notebook_widget(self):
+    def test_add_notebook_widget(self):
         notebook = self.project.service(name="Service Gears - Successful")
         widget1 = self.wm.add_notebook_widget(
             notebook=notebook,
@@ -570,7 +573,7 @@ class TestWidgetManagerInActivity(TestBetamax):
         with self.assertRaises(IllegalArgumentError):
             self.wm.add_notebook_widget(notebook="This will raise an error")
 
-    def test_multicolumn_widget(self):
+    def test_add_multicolumn_widget(self):
         bike_part = self.project.part('Bike')
         picture_instance = bike_part.property('Picture')
         picture_model = picture_instance.model()
@@ -602,7 +605,7 @@ class TestWidgetManagerInActivity(TestBetamax):
         with self.assertRaises(NotFoundError):
             parent_widget.parent()
 
-    def test_scope_widget(self):
+    def test_add_scope_widget(self):
         scope_widget = self.wm.add_scope_widget()
 
         self.assertIsInstance(scope_widget, ScopeWidget)
@@ -689,6 +692,69 @@ class TestWidgetManagerInActivity(TestBetamax):
         # tearDown
         [w.delete() for w in new_widgets]
 
+    def test_add_service_card_widget(self):
+        # setUp
+        service_gears_successful = self.project.service("Service Gears - Successful")
+        bike_part = self.project.part(name='Bike')
+        picture = bike_part.property(name='Picture')
+        title = 'Service card title'
+        description = 'The description'
+
+        widget = self.wm.add_service_card_widget(
+            service=service_gears_successful,
+            image=picture,
+            title=title,
+            description=description,
+            custom_button_text=False,
+            link=KEChainPages.EXPLORER,
+            link_target=LinkTargets.SAME_TAB,
+            image_fit=ImageFitValue.COVER
+        )
+
+        self.assertEqual(len(self.wm), 1 + 1)
+
+        self.assertIsInstance(widget, ServicecardWidget)
+        self.assertEqual(widget.title, title)
+        self.assertEqual(widget.meta.get('customText'), service_gears_successful.name)
+        self.assertEqual(widget.meta.get('customDescription'), description)
+        self.assertIn(picture.id, widget.meta.get('customImage'))
+        self.assertEqual(ImageFitValue.COVER, widget.meta.get('imageFit'))
+        self.assertEqual(CardWidgetLinkTarget.SAME_TAB, widget.meta.get('linkTarget'))
+
+    def test_add_dashboard_widget(self):
+        # setUp
+        title_widget_1 = 'Dashboard widget'
+        title_widget_2 = 'Tagged projects widget'
+
+        widget_current_project = self.wm.add_dashboard_widget(
+            title=title_widget_1,
+            show_assignees=True
+        )
+        widget_tagged_projects = self.wm.add_dashboard_widget(
+            title=title_widget_2,
+            source_scopes_tags=['catalog-scope'],
+            show_tasks=[DashboardWidgetShowTasks.UNASSIGNED_TASKS, DashboardWidgetShowTasks.CLOSED_TASKS],
+            show_scopes=[DashboardWidgetShowScopes.CLOSED_SCOPES],
+            show_assignees=False
+        )
+
+        # testing
+        self.assertIsInstance(widget_current_project, DashboardWidget)
+        self.assertIsInstance(widget_tagged_projects, DashboardWidget)
+
+        self.assertEqual(widget_current_project.title, title_widget_1)
+        self.assertEqual(widget_tagged_projects.title, title_widget_2)
+
+        self.assertTrue(all(elem['selected'] for elem in widget_current_project.meta['showNumbers']))
+        self.assertTrue(all(elem['selected'] for elem in widget_current_project.meta['showNumbersProjects']))
+
+        self.assertTrue(any(elem['selected'] is False for elem in widget_tagged_projects.meta['showNumbers']))
+        self.assertTrue(any(elem['selected'] is False for elem in widget_tagged_projects.meta['showNumbersProjects']))
+
+        self.assertTrue(widget_current_project.meta['showAssignees'])
+        self.assertFalse(widget_tagged_projects.meta['showAssignees'])
+        return
+
 
 class TestWidgetManagerWeatherWidget(TestBetamax):
     def setUp(self):
@@ -698,11 +764,12 @@ class TestWidgetManagerWeatherWidget(TestBetamax):
 
         catalog_root_model = self.project.part(name='Catalog', classification=Classification.CATALOG,
                                                category=Category.MODEL)
-        self.part_model_with_weather_prop = self.project.create_model_with_properties(parent=catalog_root_model,
-                                                              name='___TEST PART', multiplicity=Multiplicity.ONE,
-                                                              properties_fvalues=[
-                                                                  dict(name='weather',
-                                                                       property_type=PropertyType.WEATHER_VALUE)])
+        self.part_model_with_weather_prop = self.project.create_model_with_properties(
+            parent=catalog_root_model,
+            name='___TEST PART', multiplicity=Multiplicity.ONE,
+            properties_fvalues=[
+                dict(name='weather',
+                     property_type=PropertyType.WEATHER_VALUE)])
         self.weather_prop_instance = self.part_model_with_weather_prop.instances()[0].property('weather')
 
     def tearDown(self):
